var hierarchy =
[
    [ "libcamera::ipa::ipu3::algorithms::Accumulator", "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html", null ],
    [ "libcamera::ipa::AgcMeanLuminance::AgcConstraint", "structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html", null ],
    [ "libcamera::ipa::AgcMeanLuminance", "classlibcamera_1_1ipa_1_1AgcMeanLuminance.html", [
      [ "libcamera::ipa::ipu3::algorithms::Agc", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc.html", null ]
    ] ],
    [ "libcamera::ipa::Algorithm< _Module >", "classlibcamera_1_1ipa_1_1Algorithm.html", null ],
    [ "libcamera::ipa::Algorithm< Module >", "classlibcamera_1_1ipa_1_1Algorithm.html", [
      [ "libcamera::ipa::ipu3::algorithms::Af", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html", null ],
      [ "libcamera::ipa::ipu3::algorithms::Agc", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc.html", null ],
      [ "libcamera::ipa::ipu3::algorithms::Awb", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html", null ],
      [ "libcamera::ipa::ipu3::algorithms::BlackLevelCorrection", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html", null ],
      [ "libcamera::ipa::ipu3::algorithms::ToneMapping", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html", null ]
    ] ],
    [ "libcamera::ipa::AlgorithmFactoryBase< _Algorithm::Module >", null, [
      [ "libcamera::ipa::AlgorithmFactory< _Algorithm >", "classlibcamera_1_1ipa_1_1AlgorithmFactory.html", null ]
    ] ],
    [ "libcamera::ipa::CameraSensorHelper::AnalogueGainExp", "structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainExp.html", null ],
    [ "libcamera::ipa::CameraSensorHelper::AnalogueGainLinear", "structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html", null ],
    [ "libcamera::ipa::AwbAlgorithm", "classlibcamera_1_1ipa_1_1AwbAlgorithm.html", [
      [ "libcamera::ipa::AwbBayes", "classlibcamera_1_1ipa_1_1AwbBayes.html", null ],
      [ "libcamera::ipa::AwbGrey", "classlibcamera_1_1ipa_1_1AwbGrey.html", null ]
    ] ],
    [ "libcamera::ipa::AwbResult", "structlibcamera_1_1ipa_1_1AwbResult.html", null ],
    [ "libcamera::ipa::AwbStats", "structlibcamera_1_1ipa_1_1AwbStats.html", null ],
    [ "libcamera::Backtrace", "classlibcamera_1_1Backtrace.html", null ],
    [ "libcamera::BayerFormat", "classlibcamera_1_1BayerFormat.html", null ],
    [ "libcamera::ByteStreamBuffer", "classlibcamera_1_1ByteStreamBuffer.html", null ],
    [ "libcamera::CameraConfiguration", "classlibcamera_1_1CameraConfiguration.html", null ],
    [ "libcamera::CameraSensor", "classlibcamera_1_1CameraSensor.html", null ],
    [ "libcamera::CameraSensorFactoryBase", "classlibcamera_1_1CameraSensorFactoryBase.html", [
      [ "libcamera::CameraSensorFactory< _CameraSensor >", "classlibcamera_1_1CameraSensorFactory.html", null ]
    ] ],
    [ "libcamera::ipa::CameraSensorHelper", "classlibcamera_1_1ipa_1_1CameraSensorHelper.html", null ],
    [ "libcamera::ipa::CameraSensorHelperFactoryBase", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html", [
      [ "libcamera::ipa::CameraSensorHelperFactory< _Helper >", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory.html", null ]
    ] ],
    [ "libcamera::CameraSensorProperties", "structlibcamera_1_1CameraSensorProperties.html", null ],
    [ "libcamera::DebayerParams::CcmColumn", "structlibcamera_1_1DebayerParams_1_1CcmColumn.html", null ],
    [ "libcamera::ClockRecovery", "classlibcamera_1_1ClockRecovery.html", null ],
    [ "libcamera::ColorSpace", "classlibcamera_1_1ColorSpace.html", null ],
    [ "libcamera::ConditionVariable", "classlibcamera_1_1ConditionVariable.html", null ],
    [ "libcamera::ControlId", "classlibcamera_1_1ControlId.html", [
      [ "libcamera::Control< T >", "classlibcamera_1_1Control.html", null ]
    ] ],
    [ "libcamera::ControlInfo", "classlibcamera_1_1ControlInfo.html", null ],
    [ "libcamera::ControlList", "classlibcamera_1_1ControlList.html", null ],
    [ "libcamera::DelayedControls::ControlParams", "structlibcamera_1_1DelayedControls_1_1ControlParams.html", null ],
    [ "libcamera::ControlSerializer", "classlibcamera_1_1ControlSerializer.html", null ],
    [ "libcamera::ControlValidator", "classlibcamera_1_1ControlValidator.html", [
      [ "libcamera::CameraControlValidator", "classlibcamera_1_1CameraControlValidator.html", null ]
    ] ],
    [ "libcamera::ControlValue", "classlibcamera_1_1ControlValue.html", null ],
    [ "libcamera::Converter", "classlibcamera_1_1Converter.html", [
      [ "libcamera::V4L2M2MConverter", "classlibcamera_1_1V4L2M2MConverter.html", null ]
    ] ],
    [ "libcamera::ConverterFactoryBase", "classlibcamera_1_1ConverterFactoryBase.html", [
      [ "libcamera::ConverterFactory< _Converter >", "classlibcamera_1_1ConverterFactory.html", null ]
    ] ],
    [ "libcamera::Debayer", "classlibcamera_1_1Debayer.html", [
      [ "libcamera::DebayerCpu", "classlibcamera_1_1DebayerCpu.html", null ]
    ] ],
    [ "libcamera::DebayerParams", "structlibcamera_1_1DebayerParams.html", null ],
    [ "libcamera::DebugMetadata", "classlibcamera_1_1DebugMetadata.html", null ],
    [ "libcamera::DeviceEnumerator", "classlibcamera_1_1DeviceEnumerator.html", null ],
    [ "libcamera::DeviceMatch", "classlibcamera_1_1DeviceMatch.html", null ],
    [ "libcamera::DmaBufAllocator", "classlibcamera_1_1DmaBufAllocator.html", null ],
    [ "libcamera::DmaSyncer", "classlibcamera_1_1DmaSyncer.html", null ],
    [ "std::chrono::duration", null, [
      [ "libcamera::utils::Duration", "classlibcamera_1_1utils_1_1Duration.html", null ]
    ] ],
    [ "std::enable_shared_from_this", null, [
      [ "libcamera::Camera", "classlibcamera_1_1Camera.html", null ],
      [ "libcamera::PipelineHandler", "classlibcamera_1_1PipelineHandler.html", null ]
    ] ],
    [ "libcamera::EventDispatcher", "classlibcamera_1_1EventDispatcher.html", [
      [ "libcamera::EventDispatcherPoll", "classlibcamera_1_1EventDispatcherPoll.html", null ]
    ] ],
    [ "libcamera::ipa::ExposureModeHelper", "classlibcamera_1_1ipa_1_1ExposureModeHelper.html", null ],
    [ "libcamera::Extensible", "classlibcamera_1_1Extensible.html", [
      [ "libcamera::Camera", "classlibcamera_1_1Camera.html", null ],
      [ "libcamera::CameraManager", "classlibcamera_1_1CameraManager.html", null ],
      [ "libcamera::FrameBuffer", "classlibcamera_1_1FrameBuffer.html", null ],
      [ "libcamera::Request", "classlibcamera_1_1Request.html", null ]
    ] ],
    [ "libcamera::ipa::FCQueue< FrameContext >", "classlibcamera_1_1ipa_1_1FCQueue.html", null ],
    [ "libcamera::Fence", "classlibcamera_1_1Fence.html", null ],
    [ "libcamera::File", "classlibcamera_1_1File.html", null ],
    [ "libcamera::Flags< E >", "classlibcamera_1_1Flags.html", null ],
    [ "libcamera::FrameBufferAllocator", "classlibcamera_1_1FrameBufferAllocator.html", null ],
    [ "libcamera::ipa::FrameContext", "structlibcamera_1_1ipa_1_1FrameContext.html", [
      [ "libcamera::ipa::ipu3::IPAFrameContext", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html", null ]
    ] ],
    [ "libcamera::FrameMetadata", "structlibcamera_1_1FrameMetadata.html", null ],
    [ "libcamera::IPCMessage::Header", "structlibcamera_1_1IPCMessage_1_1Header.html", null ],
    [ "libcamera::ipa::Histogram", "classlibcamera_1_1ipa_1_1Histogram.html", null ],
    [ "libcamera::V4L2PixelFormat::Info", "structlibcamera_1_1V4L2PixelFormat_1_1Info.html", null ],
    [ "libcamera::ipa::Interpolator< T >", "classlibcamera_1_1ipa_1_1Interpolator.html", null ],
    [ "libcamera::ipa::Pwl::Interval", "structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html", null ],
    [ "libcamera::ipa_control_info_entry", "structlibcamera_1_1ipa__control__info__entry.html", null ],
    [ "libcamera::ipa_control_value_entry", "structlibcamera_1_1ipa__control__value__entry.html", null ],
    [ "libcamera::ipa_controls_header", "structlibcamera_1_1ipa__controls__header.html", null ],
    [ "libcamera::ipa::ipu3::IPAActiveState", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html", null ],
    [ "libcamera::IPABuffer", "structlibcamera_1_1IPABuffer.html", null ],
    [ "libcamera::IPACameraSensorInfo", "structlibcamera_1_1IPACameraSensorInfo.html", null ],
    [ "libcamera::ipa::ipu3::IPAContext", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html", null ],
    [ "libcamera::IPADataSerializer< T >", "classlibcamera_1_1IPADataSerializer.html", null ],
    [ "libcamera::IPAInterface", "classlibcamera_1_1IPAInterface.html", [
      [ "libcamera::IPAProxy", "classlibcamera_1_1IPAProxy.html", null ]
    ] ],
    [ "IPAIPU3Interface", null, [
      [ "libcamera::ipa::ipu3::IPAIPU3", "classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html", null ]
    ] ],
    [ "libcamera::IPAManager", "classlibcamera_1_1IPAManager.html", null ],
    [ "libcamera::IPAModuleInfo", "structlibcamera_1_1IPAModuleInfo.html", null ],
    [ "libcamera::ipa::ipu3::IPASessionConfiguration", "structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html", null ],
    [ "libcamera::IPASettings", "structlibcamera_1_1IPASettings.html", null ],
    [ "libcamera::IPAStream", "structlibcamera_1_1IPAStream.html", null ],
    [ "libcamera::IPCMessage", "classlibcamera_1_1IPCMessage.html", null ],
    [ "libcamera::IPCPipe", "classlibcamera_1_1IPCPipe.html", null ],
    [ "libcamera::IPCUnixSocket", "classlibcamera_1_1IPCUnixSocket.html", null ],
    [ "libcamera::LogCategory", "classlibcamera_1_1LogCategory.html", null ],
    [ "libcamera::Loggable", "classlibcamera_1_1Loggable.html", [
      [ "libcamera::ipa::Module< IPAContext, IPAFrameContext, IPAConfigInfo, ipu3_uapi_params, ipu3_uapi_stats_3a >", "classlibcamera_1_1ipa_1_1Module.html", [
        [ "libcamera::ipa::ipu3::IPAIPU3", "classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html", null ]
      ] ],
      [ "libcamera::CameraLens", "classlibcamera_1_1CameraLens.html", null ],
      [ "libcamera::IPAModule", "classlibcamera_1_1IPAModule.html", null ],
      [ "libcamera::MediaDevice", "classlibcamera_1_1MediaDevice.html", null ],
      [ "libcamera::V4L2Device", "classlibcamera_1_1V4L2Device.html", [
        [ "libcamera::V4L2Subdevice", "classlibcamera_1_1V4L2Subdevice.html", null ],
        [ "libcamera::V4L2VideoDevice", "classlibcamera_1_1V4L2VideoDevice.html", null ]
      ] ],
      [ "libcamera::ipa::Module< _Context, _FrameContext, _Config, _Params, _Stats >", "classlibcamera_1_1ipa_1_1Module.html", null ]
    ] ],
    [ "libcamera::Logger", "classlibcamera_1_1Logger.html", null ],
    [ "libcamera::LogMessage", "classlibcamera_1_1LogMessage.html", null ],
    [ "libcamera::LogOutput", "classlibcamera_1_1LogOutput.html", null ],
    [ "libcamera::ipa::LscPolynomial", "classlibcamera_1_1ipa_1_1LscPolynomial.html", null ],
    [ "libcamera::ipa::Lux", "classlibcamera_1_1ipa_1_1Lux.html", null ],
    [ "libcamera::MappedBuffer", "classlibcamera_1_1MappedBuffer.html", [
      [ "libcamera::MappedFrameBuffer", "classlibcamera_1_1MappedFrameBuffer.html", null ]
    ] ],
    [ "libcamera::Matrix< T, Rows, Cols >", "classlibcamera_1_1Matrix.html", null ],
    [ "libcamera::MediaBusFormatInfo", "classlibcamera_1_1MediaBusFormatInfo.html", null ],
    [ "libcamera::MediaObject", "classlibcamera_1_1MediaObject.html", [
      [ "libcamera::MediaEntity", "classlibcamera_1_1MediaEntity.html", null ],
      [ "libcamera::MediaLink", "classlibcamera_1_1MediaLink.html", null ],
      [ "libcamera::MediaPad", "classlibcamera_1_1MediaPad.html", null ]
    ] ],
    [ "libcamera::MediaPipeline", "classlibcamera_1_1MediaPipeline.html", null ],
    [ "libcamera::MemFd", "classlibcamera_1_1MemFd.html", null ],
    [ "libcamera::Message", "classlibcamera_1_1Message.html", [
      [ "libcamera::InvokeMessage", "classlibcamera_1_1InvokeMessage.html", null ]
    ] ],
    [ "libcamera::MessageQueue", "classlibcamera_1_1MessageQueue.html", null ],
    [ "libcamera::ipa::AwbAlgorithm::ModeConfig", "structlibcamera_1_1ipa_1_1AwbAlgorithm_1_1ModeConfig.html", null ],
    [ "libcamera::Mutex", "classlibcamera_1_1Mutex.html", null ],
    [ "libcamera::MutexLocker", "classlibcamera_1_1MutexLocker.html", null ],
    [ "libcamera::Object", "classlibcamera_1_1Object.html", [
      [ "libcamera::Camera", "classlibcamera_1_1Camera.html", null ],
      [ "libcamera::CameraManager", "classlibcamera_1_1CameraManager.html", null ],
      [ "libcamera::DebayerCpu", "classlibcamera_1_1DebayerCpu.html", null ],
      [ "libcamera::DelayedControls", "classlibcamera_1_1DelayedControls.html", null ],
      [ "libcamera::EventNotifier", "classlibcamera_1_1EventNotifier.html", null ],
      [ "libcamera::PipelineHandler", "classlibcamera_1_1PipelineHandler.html", null ],
      [ "libcamera::SoftwareIsp", "classlibcamera_1_1SoftwareIsp.html", null ],
      [ "libcamera::Timer", "classlibcamera_1_1Timer.html", null ]
    ] ],
    [ "libcamera::IPCUnixSocket::Payload", "structlibcamera_1_1IPCUnixSocket_1_1Payload.html", null ],
    [ "libcamera::PipelineHandlerFactoryBase", "classlibcamera_1_1PipelineHandlerFactoryBase.html", [
      [ "libcamera::PipelineHandlerFactory< _PipelineHandler >", "classlibcamera_1_1PipelineHandlerFactory.html", null ]
    ] ],
    [ "libcamera::PixelFormat", "classlibcamera_1_1PixelFormat.html", null ],
    [ "libcamera::PixelFormatInfo", "classlibcamera_1_1PixelFormatInfo.html", null ],
    [ "libcamera::FrameBuffer::Plane", "structlibcamera_1_1FrameBuffer_1_1Plane.html", null ],
    [ "libcamera::FrameMetadata::Plane", "structlibcamera_1_1FrameMetadata_1_1Plane.html", null ],
    [ "libcamera::PixelFormatInfo::Plane", "structlibcamera_1_1PixelFormatInfo_1_1Plane.html", null ],
    [ "libcamera::V4L2DeviceFormat::Plane", "structlibcamera_1_1V4L2DeviceFormat_1_1Plane.html", null ],
    [ "libcamera::Point", "classlibcamera_1_1Point.html", null ],
    [ "libcamera::Extensible::Private", "classlibcamera_1_1Extensible_1_1Private.html", [
      [ "libcamera::Camera::Private", "classlibcamera_1_1Camera_1_1Private.html", null ],
      [ "libcamera::FrameBuffer::Private", "classlibcamera_1_1FrameBuffer_1_1Private.html", null ],
      [ "libcamera::Request::Private", "classlibcamera_1_1Request_1_1Private.html", null ]
    ] ],
    [ "libcamera::Process", "classlibcamera_1_1Process.html", null ],
    [ "libcamera::PubKey", "classlibcamera_1_1PubKey.html", null ],
    [ "libcamera::ipa::Pwl", "classlibcamera_1_1ipa_1_1Pwl.html", null ],
    [ "libcamera::Rectangle", "classlibcamera_1_1Rectangle.html", null ],
    [ "libcamera::V4L2Subdevice::Route", "structlibcamera_1_1V4L2Subdevice_1_1Route.html", null ],
    [ "libcamera::utils::ScopeExitActions", "classlibcamera_1_1utils_1_1ScopeExitActions.html", null ],
    [ "libcamera::Semaphore", "classlibcamera_1_1Semaphore.html", null ],
    [ "libcamera::SensorConfiguration", "classlibcamera_1_1SensorConfiguration.html", null ],
    [ "libcamera::CameraSensorProperties::SensorDelays", "structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html", null ],
    [ "libcamera::SharedFD", "classlibcamera_1_1SharedFD.html", null ],
    [ "libcamera::SharedMem", "classlibcamera_1_1SharedMem.html", [
      [ "libcamera::SharedMemObject< libcamera::DebayerParams >", "classlibcamera_1_1SharedMemObject.html", null ],
      [ "libcamera::SharedMemObject< libcamera::SwIspStats >", "classlibcamera_1_1SharedMemObject.html", null ],
      [ "libcamera::SharedMemObject< T, typename >", "classlibcamera_1_1SharedMemObject.html", null ]
    ] ],
    [ "libcamera::SignalBase", null, [
      [ "libcamera::Signal< libcamera::Request *, libcamera::FrameBuffer * >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< libcamera::Request * >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< libcamera::FrameBuffer * >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< const libcamera::IPCMessage & >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< enum ExitStatus, int >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< uint32_t, uint32_t >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< uint32_t, const libcamera::ControlList & >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< const libcamera::ControlList & >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< uint32_t >", "classlibcamera_1_1Signal.html", null ],
      [ "libcamera::Signal< Args >", "classlibcamera_1_1Signal.html", null ]
    ] ],
    [ "libcamera::Size", "classlibcamera_1_1Size.html", null ],
    [ "libcamera::SizeRange", "classlibcamera_1_1SizeRange.html", null ],
    [ "libcamera::Stream", "classlibcamera_1_1Stream.html", null ],
    [ "libcamera::V4L2Subdevice::Stream", "structlibcamera_1_1V4L2Subdevice_1_1Stream.html", null ],
    [ "libcamera::StreamConfiguration", "structlibcamera_1_1StreamConfiguration.html", null ],
    [ "libcamera::StreamFormats", "classlibcamera_1_1StreamFormats.html", null ],
    [ "libcamera::SwIspStats", "structlibcamera_1_1SwIspStats.html", null ],
    [ "libcamera::SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html", null ],
    [ "libcamera::Thread", "classlibcamera_1_1Thread.html", [
      [ "libcamera::ThreadMain", "classlibcamera_1_1ThreadMain.html", null ]
    ] ],
    [ "libcamera::ThreadData", "classlibcamera_1_1ThreadData.html", null ],
    [ "libcamera::UniqueFD", "classlibcamera_1_1UniqueFD.html", null ],
    [ "std::unordered_map", null, [
      [ "libcamera::ControlInfoMap", "classlibcamera_1_1ControlInfoMap.html", null ]
    ] ],
    [ "v4l2_capability", null, [
      [ "libcamera::V4L2Capability", "structlibcamera_1_1V4L2Capability.html", null ]
    ] ],
    [ "v4l2_subdev_capability", null, [
      [ "libcamera::V4L2SubdeviceCapability", "structlibcamera_1_1V4L2SubdeviceCapability.html", null ]
    ] ],
    [ "libcamera::V4L2BufferCache", "classlibcamera_1_1V4L2BufferCache.html", null ],
    [ "libcamera::V4L2DeviceFormat", "classlibcamera_1_1V4L2DeviceFormat.html", null ],
    [ "libcamera::V4L2M2MDevice", "classlibcamera_1_1V4L2M2MDevice.html", null ],
    [ "libcamera::V4L2PixelFormat", "classlibcamera_1_1V4L2PixelFormat.html", null ],
    [ "libcamera::V4L2SubdeviceFormat", "structlibcamera_1_1V4L2SubdeviceFormat.html", null ],
    [ "libcamera::Vector< T, Rows >", "classlibcamera_1_1Vector.html", null ],
    [ "libcamera::YamlObject", "classlibcamera_1_1YamlObject.html", null ],
    [ "libcamera::YamlParser", "classlibcamera_1_1YamlParser.html", null ]
];